=====================================
toll — poor man's integration testing
=====================================

toll = **t**\ est **o**\ ffline **l**\ ocally **l**\ ightweight

Run the tests of multiple configured packages:

* right one package after another

* stopping with the first package which has a failing test

This package is compatible with Python version 3.5.

Documentation see: https://pythonhosted.org/toll/
